Crate riff_wave_core

Crate riff_wave_core 

Sans-IO RIFF/WAVE (PCM) mux and demux — no OS I/O, no Mediaway types.

  • Muxer buffers pushed PCM samples and writes a complete RIFF/WAVE file on Muxer::finish — RIFF’s data chunk size must be known before the header is written, so (unlike iso-bmff’s fragmented fMP4 output) there is no incremental flush here.
  • parse reads a complete RIFF/WAVE buffer back into a WaveFormat and raw PCM bytes::Bytes payload.

Structs

Muxer
Builds a single RIFF/WAVE file from pushed PCM samples.
WaveFormat
fmt chunk contents — enough to interpret the raw PCM data chunk.

Enums

Error
Errors from RIFF/WAVE demux.
SampleFormat
wFormatTag sample encoding.

Functions

parse
Parse a complete RIFF/WAVE byte buffer into its format and raw PCM data payload.