Sans-IO RIFF/WAVE (PCM) mux and demux — no OS I/O, no Mediaway types.
Muxerbuffers pushed PCM samples and writes a complete RIFF/WAVE file onMuxer::finish— RIFF’sdatachunk size must be known before the header is written, so (unlikeiso-bmff’s fragmented fMP4 output) there is no incremental flush here.parsereads a complete RIFF/WAVE buffer back into aWaveFormatand raw PCMbytes::Bytespayload.
Structs
- Muxer
- Builds a single RIFF/WAVE file from pushed PCM samples.
- Wave
Format fmtchunk contents — enough to interpret the raw PCMdatachunk.
Enums
- Error
- Errors from RIFF/WAVE demux.
- Sample
Format wFormatTagsample encoding.
Functions
- parse
- Parse a complete RIFF/WAVE byte buffer into its format and raw PCM
datapayload.